# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdConfigProvider(Component):
    """An AntdConfigProvider component.
参数配置组件AntdConfigProvider

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- algorithm (a value equal to: 'default', 'dark', 'compact' | list of a value equal to: 'default', 'dark', 'compact's; default 'default'):
    为内部组件设置快捷主题算法，支持多种主题组合，可选项有`'default'`、`'dark'`、`'compact'`
    默认值：`'default'`.

- useOldTheme (a value equal to: 'default', 'dark'; optional):
    是否强制使用`0.3.x`版本之前的主题样式，可选项有`'default'`、`'dark'`.

- primaryColor (string; optional):
    主题色.

- componentDisabled (boolean; optional):
    是否针后代元素中的所有组件强制设置禁用状态.

- componentSize (a value equal to: 'small', 'middle', 'large'; optional):
    强制设置后代元素的尺寸规格，可选项有`'small'`、`'middle'`、`'large'`，其中`'default'`兼容`'middle'`.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de'; optional):
    强制设置后代元素的语言，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）.

- wavesDisabled (boolean; default False):
    是否禁用内部组件水波纹动效  默认值：`False`.

- token (dict; optional):
    配置`design token`相关参数.

    `token` is a dict with keys:

    - motion (boolean; optional):
        是否开启动画效果  默认值：`True`.

- componentsToken (dict; optional):
    配置针对具体组件的`design token`相关参数.

    `componentsToken` is a dict with strings as keys and values of
    type dict with keys:

    - algorithm (boolean; optional):
        是否开启派生样式自动推导运算  默认值：`False`.

- compatibilityMode (boolean; default False):
    是否开启针对`88`及以下版本`Chromium`内核浏览器的向下兼容模式  默认值：`False`.

- enableLayer (boolean; default False):
    是否启用layer样式降权  默认值：`False`.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdConfigProvider'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, algorithm=Component.UNDEFINED, useOldTheme=Component.UNDEFINED, primaryColor=Component.UNDEFINED, componentDisabled=Component.UNDEFINED, componentSize=Component.UNDEFINED, locale=Component.UNDEFINED, wavesDisabled=Component.UNDEFINED, token=Component.UNDEFINED, componentsToken=Component.UNDEFINED, compatibilityMode=Component.UNDEFINED, enableLayer=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'algorithm', 'useOldTheme', 'primaryColor', 'componentDisabled', 'componentSize', 'locale', 'wavesDisabled', 'token', 'componentsToken', 'compatibilityMode', 'enableLayer', 'loading_state']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'key', 'children', 'algorithm', 'useOldTheme', 'primaryColor', 'componentDisabled', 'componentSize', 'locale', 'wavesDisabled', 'token', 'componentsToken', 'compatibilityMode', 'enableLayer', 'loading_state']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdConfigProvider, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdTabs(Component):
    """An AntdTabs component.
标签页组件AntdTabs

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- type (a value equal to: 'line', 'card', 'editable-card'; default 'line'):
    标签页类型，可选项有`'line'`、`'card'`、`'editable-card'`  默认值：`'line'`.

- items (list of dicts; optional):
    定义标签项.

    `items` is a list of dicts with keys:

    - label (a list of or a singular dash component, string or number; optional):
        组件型，标签页标题.

    - key (string; optional):
        标签页唯一识别id.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，标签页内部元素.

    - closeIcon (boolean | a list of or a singular dash component, string or number; optional):
        `'editable-card'`型标签页可用，用于自定义关闭按钮，设置为`None`或`False`时会隐藏默认的关闭按钮.

    - destroyInactiveTabPane (boolean; optional):
        是否在当前标签页隐藏时，自动销毁当前标签页内部元素  默认值：`False`.

    - disabled (boolean; optional):
        是否禁用当前标签页  默认值：`False`.

    - forceRender (boolean; optional):
        初始化是否强制渲染当前标签页内部元素  默认值：`False`.

    - closable (boolean; optional):
        `'editable-card'`型标签页可用，控制当前标签页是否可被关闭  默认值：`True`.

    - contextMenu (list of dicts; optional):
        为当前标签页标题配置右键菜单相关参数.

        `contextMenu` is a list of dicts with keys:

        - key (string; optional):

            当前右键菜单项唯一标识id.

        - label (string; optional):

            当前右键菜单项标题.

        - icon (string; optional):

            当前右键菜单项前缀图标类型，`iconRenderer`为`'AntdIcon'`时同`AntdIcon`同名参数，`iconRenderer`为`'fontawesome'`时为css类名.

        - iconRenderer (a value equal to: 'AntdIcon', 'fontawesome'; optional):

            当前右键菜单项前缀图标渲染方式，可选项有`'AntdIcon'`、`'fontawesome'`.

- itemKeys (list of strings; optional):
    监听当前各标签页`key`值，顺序与`items`一致.

- activeKey (string; optional):
    监听或设置当前激活的标签页对应`key`值.

- defaultActiveKey (string; optional):
    初始化激活的标签页对应`key`值.

- disabledTabKeys (list of strings; optional):
    呈现禁用状态的标签页`key`值数组，优先级高于`items`中各标签页的`disabled`设定.

- tabPosition (a value equal to: 'top', 'left', 'right', 'bottom'; default 'top'):
    标签页切换控件显示方位，可选项有`'top'`、`'left'`、`'right'`、`'bottom'`
    默认值：`'top'`.

- size (a value equal to: 'small', 'default', 'large'; default 'default'):
    当前组件尺寸规格，可选项有`'small'`、`'default'`、`'large'`  默认值：'default'.

- centered (boolean; default False):
    是否居中显示标签页切换控件  默认值：`False`.

- indicator (dict; optional):
    配置指示条长度及对齐方式.

    `indicator` is a dict with keys:

    - size (number; optional):
        指示条像素宽度，当传入负数时，表示在完整宽度基础上应减去的像素宽度，默认与标签卡片同宽.

    - align (a value equal to: 'start', 'center', 'end'; optional):
        指示条对齐方式，可选项有`'start'`、`'center'`、`'end'`.

- tabBarGutter (number; optional):
    标签卡片之间的像素间距.

- inkBarAnimated (boolean; default True):
    标签卡片切换是否添加动画效果  默认值：`True`.

- tabPaneAnimated (boolean; default False):
    标签内容切换是否添加动画效果  默认值：`False`.

- latestDeletePane (string; optional):
    监听最近一次删除操作对应的标签页`key`值.

- tabCloseCounts (number; default 0):
    标签页关闭按钮累计点击次数  默认值：`0`.

- tabBarLeftExtraContent (a list of or a singular dash component, string or number; optional):
    组件型，第一方位额外元素.

- tabBarRightExtraContent (a list of or a singular dash component, string or number; optional):
    组件型，第二方位额外元素.

- tabCount (number; optional):
    监听标签页数量.

- destroyInactiveTabPane (boolean; default False):
    统一设置是否自动销毁取消激活状态的标签页内部元素.

- clickedContextMenu (dict; optional):
    监听标签页标题右键菜单项相关点击事件.

    `clickedContextMenu` is a dict with keys:

    - tabKey (string; optional):
        被点击的右键菜单项对应标签页`key`值.

    - menuKey (string; optional):
        被点击的右键菜单项对应`key`值.

    - timestamp (number; optional):
        事件对应时间戳信息.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading.

- persistence (boolean | string | number; optional):
    是否开启[属性持久化](/prop-persistence).

- persisted_props (list of a value equal to: 'activeKey's; default ['activeKey']):
    开启属性持久化功能的若干属性名，可选项有`'activeKey'`  默认值：`['activeKey']`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
    默认值：`'local'`."""
    _children_props = ['items[].label', 'items[].children', 'items[].closeIcon', 'tabBarLeftExtraContent', 'tabBarRightExtraContent']
    _base_nodes = ['tabBarLeftExtraContent', 'tabBarRightExtraContent', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTabs'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, type=Component.UNDEFINED, items=Component.UNDEFINED, itemKeys=Component.UNDEFINED, activeKey=Component.UNDEFINED, defaultActiveKey=Component.UNDEFINED, disabledTabKeys=Component.UNDEFINED, tabPosition=Component.UNDEFINED, size=Component.UNDEFINED, centered=Component.UNDEFINED, indicator=Component.UNDEFINED, tabBarGutter=Component.UNDEFINED, inkBarAnimated=Component.UNDEFINED, tabPaneAnimated=Component.UNDEFINED, latestDeletePane=Component.UNDEFINED, tabCloseCounts=Component.UNDEFINED, tabBarLeftExtraContent=Component.UNDEFINED, tabBarRightExtraContent=Component.UNDEFINED, tabCount=Component.UNDEFINED, destroyInactiveTabPane=Component.UNDEFINED, clickedContextMenu=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'style', 'className', 'type', 'items', 'itemKeys', 'activeKey', 'defaultActiveKey', 'disabledTabKeys', 'tabPosition', 'size', 'centered', 'indicator', 'tabBarGutter', 'inkBarAnimated', 'tabPaneAnimated', 'latestDeletePane', 'tabCloseCounts', 'tabBarLeftExtraContent', 'tabBarRightExtraContent', 'tabCount', 'destroyInactiveTabPane', 'clickedContextMenu', 'data-*', 'aria-*', 'loading_state', 'persistence', 'persisted_props', 'persistence_type']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'type', 'items', 'itemKeys', 'activeKey', 'defaultActiveKey', 'disabledTabKeys', 'tabPosition', 'size', 'centered', 'indicator', 'tabBarGutter', 'inkBarAnimated', 'tabPaneAnimated', 'latestDeletePane', 'tabCloseCounts', 'tabBarLeftExtraContent', 'tabBarRightExtraContent', 'tabCount', 'destroyInactiveTabPane', 'clickedContextMenu', 'data-*', 'aria-*', 'loading_state', 'persistence', 'persisted_props', 'persistence_type']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdTabs, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdFormRender(Component):
    """An AntdFormRender component.


Keyword arguments:

- id (string; optional):
    组件id.

- className (string | dict; optional):
    css类名.

- style (dict; optional):
    自定义css字典.

- key (string; optional):
    辅助刷新用唯一标识key值.

- schema (dict; required):
    必填，设置表单的schema.

    `schema` is a dict with keys:

    - type (a value equal to: 'object'; optional):
        固定配置为type: 'object'.

    - displayType (a value equal to: 'column', 'row', 'inline'; optional):
        设置表单表单项label布局方式，可选的有'column'、'row'与'inline'，默认为'column'.

    - column (number; optional):
        设置表单布局，一行应该有几列，默认为3.

    - labelWidth (number; optional):
        设置表单项标签的宽度.

    - maxWidth (number; optional):
        设置表单项控件的最大宽度.

    - labelCol (number; optional):
        设置表单标签占位格数.

    - fieldCol (number; optional):
        设置表单控件占位格数.

    - properties (dict; optional):
        设置表单控件.

        `properties` is a dict with strings as keys and values of type
        dict with keys:

        - type (a value equal to: 'string', 'number', 'boolean', 'array', 'range', 'html', 'block'; optional):

            设置表单字段的类型，可选的有'string'、'number'、'boolean'、'array'、'range'、'html'、'block'.

        - title (string; optional):

            设置表单字段的标签.

        - labelWidth (number

              Or string; optional):

            设置表单项标签的宽度.

        - maxWidth (number

      Or string; optional):

            设置表单项控件的最大宽度.

        - labelCol (number | string; optional):

            设置表单标签占位格数.

        - fieldCol (number | string; optional):

            设置表单控件占位格数.

        - cellSpan (number | string; optional):

            设置表单项跨列展示，目前需配合lableWidth来使用，否则无法与其他表单项在样式上对齐，通过配置单个表单项的labelCol、fieldCol勉强能改善.

        - span (number | string; optional):

            设置表单项列宽度，表单布局会被切割成 24 等份，可以通过设置 span 来自定义表单项所占的宽度.

        - widget (a value equal to: 'input', 'inputNumber', 'select', 'multiSelect', 'radio', 'checkboxes', 'textArea', 'checkbox', 'switch', 'rate', 'slider', 'datePicker', 'dateRange', 'timePicker', 'timeRange', 'cascader', 'treeSelect', 'color', 'imageInput', 'urlInput', 'html'; optional):

            设置指定渲染的控件名称.

        - placeholder (string | list of strings; optional):

            设置输入内容提示.

        - description (string; optional):

            设置副标题描述.

        - tooltip (dict; optional):

            设置气泡提示，支持html格式，可传入一个antd的tooltip配置对象支持更多配置.

            `tooltip` is a string | dict with keys:

            - title (boolean | number | string | dict | list; optional):

                设置显示的文字内容.

            - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight'; optional):

                设置气泡框的位置，可选的有'top'、'left'、'right'、'bottom'、'topLeft'

                、'topRight'、'bottomLeft'、'bottomRight'、'leftTop'、'leftBottom'

                、'rightTop'、'rightBottom'，默认为'top'.

            - color (string; optional):

                设置背景颜色.

            - mouseEnterDelay (number; optional):

                设置鼠标移入后延时多少才显示 Tooltip，单位：秒，默认为0.1.

            - mouseLeaveDelay (number; optional):

                设置鼠标移出后延时多少才隐藏 Tooltip，单位：秒，默认为0.1.

            - overlayClassName (string | dict; optional):

                设置卡片css类.

            - overlayStyle (dict; optional):

                设置卡片样式.

            - overlayInnerStyle (dict; optional):

                设置卡片内容区域的样式.

            - trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; optional):

                设置触发行为，可选的有'hover'、'focus'、'click'，或是以上多个组成的数组，默认为'hover'.

            - zIndex (number; optional):

                设置悬浮层zIndex.

            - arrow (a value equal to: 'show', 'hide', 'center'; optional):

                设置修改箭头的显示状态以及修改箭头是否指向目标元素中心，默认为'show'.

            - fresh (boolean; optional):

                用于设置是否始终保持更新内容，默认为False。默认情况下，Tooltip

                在关闭时会缓存内容，设置该属性后会始终保持更新。.

            - open (boolean; optional):

                用于监听或控制当前tooltip的显隐，默认为False.

            - autoAdjustOverflow (boolean; optional):

                用于设置气泡被遮挡时自动调整位置,默认为True.

            - defaultOpen (boolean; optional):

                设置默认是否显隐，默认为False.

            - destroyTooltipOnHide (boolean; optional):

                设置关闭后是否销毁Tooltip，默认为False.

        - extra (string; optional):

            设置更多的说明信息，支持html格式，会紧贴在元素下面一行展示.

        - required (boolean | string; optional):

            设置是否必填，默认为False.

        - min (number | string; optional):

            设置string类型为字符串最小长度；number类型时为最小值；array 类型时为数组最小长度.

        - max (number | string; optional):

            设置string类型为字符串最大长度；number类型时为最大值；array 类型时为数组最大长度.

        - format (a value equal to: 'image', 'textarea', 'color', 'email', 'url', 'dateTime', 'date', 'time', 'upload'; optional):

            在已设置的type下，如何处理这个type.

        - rules (list of dicts; optional):

            设置表单元素的校验规则.

            `rules` is a list of dicts with keys:

            - defaultField (dict; optional):

                仅在 type 为 array 类型时有效，用于指定数组元素的校验规则.

            - enum (boolean | number | string | dict | list; optional):

                是否匹配枚举中的值（需要将 type 设置为 enum）.

            - fields (boolean | number | string | dict | list; optional):

                仅在 type 为 array 或 object 类型时有效，用于指定子元素的校验规则.

            - len (number; optional):

                string 类型时为字符串长度；number 类型时为确定数字； array 类型时为数组长度.

            - max (number; optional):

                必须设置 type：string 类型为字符串最大长度；number 类型时为最大值；array 类型时为数组最大长度.

            - message (string; optional):

                错误信息，不设置时会通过模板自动生成.

            - min (number; optional):

                必须设置 type：string 类型为字符串最小长度；number 类型时为最小值；array 类型时为数组最小长度.

            - pattern (string; optional):

                正则表达式匹配.

            - required (boolean; optional):

                是否为必选字段.

            - type (a value equal to: 'string', 'number', 'boolean', 'method', 'regexp', 'integer', 'float', 'array', 'object', 'enum', 'date', 'url', 'hex', 'email', 'any'; optional):

                类型，常见有 string |number |boolean |url | email等.

            - validateTrigger (a value equal to: 'onChange', 'onBlur', 'onFocus'; optional):

                设置触发验证时机，可选值有onChange、onBlur、onFocus，默认为onChange.

            - validator (string; optional):

                设置自定义校验，值需要是字符串格式的js函数.

            - warningOnly (boolean; optional):

                仅警告，不阻塞表单提交.

            - whitespace (boolean; optional):

                如果字段仅包含空格则校验不通过，只在 type: 'string' 时生效.

        - hidden (boolean | string; optional):

            设置是否隐藏，默认为False.

        - disabled (boolean | string; optional):

            设置是否禁用，默认为False.

        - readOnly (boolean | string; optional):

            设置是否为可读模式，默认为False.

        - readOnlyWidget (string; optional):

            指定只读渲染组件名称.

        - dependencies (list of strings; optional):

            设置表单依赖元素，当依赖的元素更新时，会触发本元素的重新渲染，用于复杂的表单联动.

        - className (string; optional):

            设置自定义控件class名称.

        - reserveLabel (boolean | string; optional):

            当title未设置时，通过配置reserveLabel:

            True可以保留labelWidth占位，使得输入控件和其他控件上下对齐.

        - props (dict; optional):

            设置额外属性，如果使用的是antd组件，对应的就是antd组件的其他属性. | dict with keys:

        - type (a value equal to: 'object'; optional):

            固定配置为type: 'object'.

        - title (string; optional):

            设置标题.

        - widget (a value equal to: 'collapse', 'card', 'lineTitle', 'subInline'; optional):

            设置希望使用的嵌套组件名称，可选的有'collapse'、'card'、'lineTitle'、'subInline'，默认为'card'.

        - properties (dict; optional):

            设置表单元素集合.

        - column (number | string; optional):

            设置表单布局，一行应该有几列，默认为3.

        - description (string; optional):

            设置副标题描述.

        - tooltip (dict; optional):

            设置气泡提示，支持html格式，可传入一个antd的tooltip配置对象支持更多配置.

            `tooltip` is a string | dict with keys:

            - title (boolean | number | string | dict | list; optional):

                设置显示的文字内容.

            - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight'; optional):

                设置气泡框的位置，可选的有'top'、'left'、'right'、'bottom'、'topLeft'

                、'topRight'、'bottomLeft'、'bottomRight'、'leftTop'、'leftBottom'

                、'rightTop'、'rightBottom'，默认为'top'.

            - color (string; optional):

                设置背景颜色.

            - mouseEnterDelay (number; optional):

                设置鼠标移入后延时多少才显示 Tooltip，单位：秒，默认为0.1.

            - mouseLeaveDelay (number; optional):

                设置鼠标移出后延时多少才隐藏 Tooltip，单位：秒，默认为0.1.

            - overlayClassName (string | dict; optional):

                设置卡片css类.

            - overlayStyle (dict; optional):

                设置卡片样式.

            - overlayInnerStyle (dict; optional):

                设置卡片内容区域的样式.

            - trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; optional):

                设置触发行为，可选的有'hover'、'focus'、'click'，或是以上多个组成的数组，默认为'hover'.

            - zIndex (number; optional):

                设置悬浮层zIndex.

            - arrow (a value equal to: 'show', 'hide', 'center'; optional):

                设置修改箭头的显示状态以及修改箭头是否指向目标元素中心，默认为'show'.

            - fresh (boolean; optional):

                用于设置是否始终保持更新内容，默认为False。默认情况下，Tooltip

                在关闭时会缓存内容，设置该属性后会始终保持更新。.

            - open (boolean; optional):

                用于监听或控制当前tooltip的显隐，默认为False.

            - autoAdjustOverflow (boolean; optional):

                用于设置气泡被遮挡时自动调整位置,默认为True.

            - defaultOpen (boolean; optional):

                设置默认是否显隐，默认为False.

            - destroyTooltipOnHide (boolean; optional):

                设置关闭后是否销毁Tooltip，默认为False.

        - props (dict; optional):

            设置额外属性，透传到对应的嵌套组件中. | dict with keys:

        - type (a value equal to: 'array'; optional):

            固定配置为type: 'array'.

        - title (string; optional):

            设置标题.

        - widget (a value equal to: 'cardList', 'simpleList', 'tableList', 'drawerList', 'virtualList'; optional):

            设置希望使用的列表组件名称，可选的有'cardList'、'simpleList'、'tableList'、'drawerList'、'virtualList'，默认为'cardList'.

        - max (number | string; optional):

            设置列表的最大长度.

        - min (number | string; optional):

            设置列表的最小长度.

        - props (dict; optional):

            设置列表控件.

            `props` is a dict with keys:

            - addBtnProps (dict; optional):

                设置添加按钮属性，参考 Antd Button Props().

            - delConfirmProps (dict; optional):

                设置删除确认弹窗属性，参考 Antd PopConfirm Props.

            - actionColumnProps (dict; optional):

                设置tableList | drawerList | virtualList 中操作列的属性，参考 Antd

                Table ColumnType。 其中 title 使用 colHeaderText 代替。.

            - hideAdd (boolean; optional):

                设置是否隐藏添加按钮.

            - hideCopy (boolean; optional):

                设置是否隐藏复制按钮.

            - hideMove (boolean; optional):

                设置是否隐藏移动按钮.

            - hideDelete (boolean; optional):

                设置是否隐藏删除按钮.

        - items (dict; optional):

            动态项配置，可以是一个嵌套控件.

- displayType (a value equal to: 'column', 'row', 'inline'; default 'column'):
    设置表单布局模式，表单元素与 label 同行 or 分两行展示, inline 则整个展示自然顺排，
    可选的有'column'、'row'与'inline'，默认为'column'.

- labelAlign (a value equal to: 'left', 'right'; default 'right'):
    设置label标签的文本对齐方式，可选的有'left'和'right'，默认为'right'.

- lableWidth (number; optional):
    设置表单标签固定宽度.

- maxWidth (number; optional):
    设置表单项控件的最大宽度.

- labelCol (number; optional):
    设置表单标签占位格数.

- fieldCol (number; optional):
    设置表单控件占位格数.

- colon (boolean; default True):
    设置是否是否显示label后面的冒号，默认为True.

- globalConfig (dict; optional):
    设置表单全局配置.

    `globalConfig` is a dict with keys:

    - mustacheDisabled (boolean; optional):
        设置是否禁用表达式.

    - listOperate (dict; optional):
        设置列表表单配置.

        `listOperate` is a dict with keys:

        - btnType (a value equal to: 'icon', 'text'; optional):
            设置列表表单操作按钮样式.

        - hideMove (boolean; optional):
            设置是否隐藏移动按钮.

- watch (dict with strings as keys and values of type string; optional):
    监听表单的数据变化，属性值需要是字符串格式的js函数.

- removeHiddenData (boolean; default True):
    设置提交数据的时候是否去掉已经被隐藏的元素的数据，默认为True.

- readOnly (boolean; default False):
    设否开启只读模式，一般用于预览展示，全文text展示，默认为False.

- column (number; default 1):
    设置一行展示多少列.

- disabled (boolean; default False):
    设置是否禁用全部表单项，默认为False.

- scrollToFirstError (boolean; default False):
    设置提交失败是否自动滚动到第一个错误字段，默认为False.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de'; default 'zh-CN'):
    设置展示语言，目前只支持中文、英文，  可选的有'zh-CN'与'en-US'，默认为'zh-CN'.

- footer (dict; optional):
    设置底部操作区域.

    `footer` is a boolean | dict with keys:

    - submit (dict; optional):
        设置提交按钮.

        `submit` is a dict with keys:

        - text (string; optional):
            设置按钮文字.

        - hide (boolean; optional):
            设置是否显示.

        - btnProps (dict; optional):
            设置其他按钮属性，参考 Antd Button Props().

    - reset (dict; optional):
        设置重置按钮.

        `reset` is a dict with keys:

        - text (string; optional):
            设置按钮文字.

        - hide (boolean; optional):
            设置是否显示.

        - btnProps (dict; optional):
            设置其他按钮属性，参考 Antd Button Props(). | a list of or a singular dash component, string or number

- configProvider (dict; optional):
    同antd的configProvider.

- validateMessages (dict; optional):
    设置默认的校验提示信息.

    `validateMessages` is a dict with keys:

    - default (string; optional)

    - required (string; optional)

    - whitespace (string; optional)

    - date (dict; optional)

        `date` is a dict with keys:

        - format (string; optional)

        - parse (string; optional)

        - invalid (string; optional)

    - types (dict; optional)

        `types` is a dict with keys:

        - string (string; optional)

        - method (string; optional)

        - array (string; optional)

        - object (string; optional)

        - number (string; optional)

        - date (string; optional)

        - boolean (string; optional)

        - integer (string; optional)

        - float (string; optional)

        - regexp (string; optional)

        - email (string; optional)

        - url (string; optional)

        - hex (string; optional)

    - string (dict; optional)

        `string` is a dict with keys:

        - len (string; optional)

        - min (string; optional)

        - max (string; optional)

        - range (string; optional)

    - number (dict; optional)

        `number` is a dict with keys:

        - len (string; optional)

        - min (string; optional)

        - max (string; optional)

        - range (string; optional)

    - array (dict; optional)

        `array` is a dict with keys:

        - len (string; optional)

        - min (string; optional)

        - max (string; optional)

        - range (string; optional)

    - pattern (dict; optional)

        `pattern` is a dict with keys:

        - mismatch (string; optional)

- values (dict; optional):
    设置与监听表单数据.

- validateStatuses (boolean; optional):
    监听表单校验结果.

- submitForm (boolean; optional):
    控制参数，用于提交表单时手动搜集表单的校验结果，回调设置为True后会自动变为False.

- submitFormClicks (number; default 0):
    辅助监听表单提交参数.

- resetForm (boolean; optional):
    控制参数，用于重置表单项校验状态（不能重置表单项包裹的组件的值，需要通过回调重置表单项包裹的组件的值），回调设置为True后会自动变为False.

- resetFormClicks (number; default 0):
    辅助监听表单重置参数.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = ['footer']
    _base_nodes = ['footer', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFormRender'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, schema=Component.REQUIRED, displayType=Component.UNDEFINED, labelAlign=Component.UNDEFINED, lableWidth=Component.UNDEFINED, maxWidth=Component.UNDEFINED, labelCol=Component.UNDEFINED, fieldCol=Component.UNDEFINED, colon=Component.UNDEFINED, globalConfig=Component.UNDEFINED, watch=Component.UNDEFINED, removeHiddenData=Component.UNDEFINED, readOnly=Component.UNDEFINED, column=Component.UNDEFINED, disabled=Component.UNDEFINED, scrollToFirstError=Component.UNDEFINED, locale=Component.UNDEFINED, footer=Component.UNDEFINED, configProvider=Component.UNDEFINED, validateMessages=Component.UNDEFINED, values=Component.UNDEFINED, validateStatuses=Component.UNDEFINED, submitForm=Component.UNDEFINED, submitFormClicks=Component.UNDEFINED, resetForm=Component.UNDEFINED, resetFormClicks=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'style', 'key', 'schema', 'displayType', 'labelAlign', 'lableWidth', 'maxWidth', 'labelCol', 'fieldCol', 'colon', 'globalConfig', 'watch', 'removeHiddenData', 'readOnly', 'column', 'disabled', 'scrollToFirstError', 'locale', 'footer', 'configProvider', 'validateMessages', 'values', 'validateStatuses', 'submitForm', 'submitFormClicks', 'resetForm', 'resetFormClicks', 'loading_state']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'style', 'key', 'schema', 'displayType', 'labelAlign', 'lableWidth', 'maxWidth', 'labelCol', 'fieldCol', 'colon', 'globalConfig', 'watch', 'removeHiddenData', 'readOnly', 'column', 'disabled', 'scrollToFirstError', 'locale', 'footer', 'configProvider', 'validateMessages', 'values', 'validateStatuses', 'submitForm', 'submitFormClicks', 'resetForm', 'resetFormClicks', 'loading_state']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['schema']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(AntdFormRender, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdFlex(Component):
    """An AntdFlex component.
弹性布局组件AntdFlex

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- vertical (boolean; default False):
    是否使用垂直主轴  默认值：`False`.

- wrap (string | boolean; default 'nowrap'):
    子元素换行显示行为，同css中的flex-wrap，也可直接传入布尔型设置是否自动换行  默认值：`'nowrap'`.

- justify (string; default 'normal'):
    子元素在主轴方向上的对齐方式，同css中的justify-content  默认值：`'normal'`.

- align (string; default 'normal'):
    子元素在交叉轴方向上的对齐方式，同css中的align-items  默认值：`'normal'`.

- flex (string; default 'normal'):
    同css中的flex  默认值：`'normal'`.

- gap (string | number | a value equal to: 'small', 'middle', 'large'; optional):
    子元素之间的间隙，可选项有`'small'`、`'middle'`、`'large'`，也可传入字符型css宽度，或数值型像素宽度.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFlex'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, vertical=Component.UNDEFINED, wrap=Component.UNDEFINED, justify=Component.UNDEFINED, align=Component.UNDEFINED, flex=Component.UNDEFINED, gap=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'vertical', 'wrap', 'justify', 'align', 'flex', 'gap', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'vertical', 'wrap', 'justify', 'align', 'flex', 'gap', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFlex, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdNotification(Component):
    """An AntdNotification component.
通知提醒框组件AntdNotification

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- message (string; optional):
    通知提醒主要信息.

- description (string; optional):
    通知提醒描述信息.

- type (a value equal to: 'default', 'success', 'error', 'info', 'warning'; default 'default'):
    通知提醒类型，可选项有`'default'`、`'success'`、`'error'`、`'info'`、`'warning'`
    默认值：`'default'`.

- placement (a value equal to: 'top', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight'; default 'topRight'):
    通知提醒框在屏幕中的弹出位置，可选项有`'top'`、`'bottom'`、`'topLeft'`、`'topRight'`、`'bottomLeft'`、`'bottomRight'`
    默认值：`'topRight'`.

- top (number; default 24):
    当通知从顶部弹出时，设置距离顶部的像素距离  默认值：`24`.

- bottom (number; default 24):
    当通知从底部弹出时，设置距离底部的像素距离  默认值：`24`.

- duration (number; default 4.5):
    通知从显示到自动消失的时长，单位：秒，当传入`None`时会一直显示  默认值：`4.5`.

- closable (boolean; default True):
    是否显示关闭按钮  默认值：`True`.

- closeButton (dict; optional):
    配置右下方关闭按钮相关参数，默认不显示关闭按钮.

    `closeButton` is a dict with keys:

    - content (string; optional):
        按钮内容.

    - style (dict; optional):
        按钮css样式.

    - className (string; optional):
        按钮css类名.

    - type (a value equal to: 'default', 'primary', 'ghost', 'dashed', 'link', 'text'; optional):
        按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
        默认值：`'default'`.

    - danger (boolean; optional):
        按钮是否呈现危险状态  默认值：`False`.

- underCompatibilityMode (boolean; optional):
    当前通知提醒框组件是否位于设置了`compatibilityMode=True`的`AntdConfigProvider`内部.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdNotification'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, message=Component.UNDEFINED, description=Component.UNDEFINED, type=Component.UNDEFINED, placement=Component.UNDEFINED, top=Component.UNDEFINED, bottom=Component.UNDEFINED, duration=Component.UNDEFINED, closable=Component.UNDEFINED, closeButton=Component.UNDEFINED, underCompatibilityMode=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'style', 'className', 'message', 'description', 'type', 'placement', 'top', 'bottom', 'duration', 'closable', 'closeButton', 'underCompatibilityMode', 'loading_state']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'key', 'style', 'className', 'message', 'description', 'type', 'placement', 'top', 'bottom', 'duration', 'closable', 'closeButton', 'underCompatibilityMode', 'loading_state']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdNotification, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdSpoiler(Component):
    """An AntdSpoiler component.
展开收起组件AntdSpoiler

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- contentClassName (string | dict; optional):
    内容区css类名，支持[动态css](/advanced-classname).

- contentStyle (dict; optional):
    内容区css样式.

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）
    默认值：`'zh-cn'`.

- hideLabel (a list of or a singular dash component, string or number; optional):
    组件型，展开状态下，收起按钮的文案内容.

- showLabel (a list of or a singular dash component, string or number; optional):
    组件型，收起状态下，展开按钮的文案内容.

- labelPosition (a value equal to: 'left', 'right'; default 'left'):
    展开/收起按钮的位置，可选项有`'left'`、`'right'`  默认值：`'left'`.

- open (boolean; default False):
    监听或设置是否处于展开状态  默认值：`False`.

- maxHeight (number; default 50):
    收起状态下，内容区域最大像素高度  默认值：`50`.

- transitionDuration (number; default 0.1):
    展开/收起过渡动画耗时，单位：秒  默认值：`0.1`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = ['hideLabel', 'showLabel']
    _base_nodes = ['hideLabel', 'showLabel', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSpoiler'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, contentClassName=Component.UNDEFINED, contentStyle=Component.UNDEFINED, locale=Component.UNDEFINED, hideLabel=Component.UNDEFINED, showLabel=Component.UNDEFINED, labelPosition=Component.UNDEFINED, open=Component.UNDEFINED, maxHeight=Component.UNDEFINED, transitionDuration=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'contentClassName', 'contentStyle', 'locale', 'hideLabel', 'showLabel', 'labelPosition', 'open', 'maxHeight', 'transitionDuration', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'contentClassName', 'contentStyle', 'locale', 'hideLabel', 'showLabel', 'labelPosition', 'open', 'maxHeight', 'transitionDuration', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSpoiler, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdRow(Component):
    """An AntdRow component.
行组件AntdRow

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- align (a value equal to: 'top', 'middle', 'bottom'; default 'top'):
    竖直方向对齐方式，可选项有`'top'`、`'middle'`、`'bottom'`  默认值：`'top'`.

- gutter (dict; default 0):
    网格间隔，传入数值型时为水平像素间隔，传入数组时分别设置水平、垂直像素间隔，传入字典时可为响应式各断点设置水平像素间隔.

    `gutter` is a number | list of numbers | dict with keys:

    - xs (number; optional):
        页面宽度小于567px时的水平像素间隔.

    - sm (number; optional):
        页面宽度大于等于567px时的水平像素间隔.

    - md (number; optional):
        页面宽度大于等于768px时的水平像素间隔.

    - lg (number; optional):
        页面宽度大于等于992px时的水平像素间隔.

    - xl (number; optional):
        页面宽度大于等于1200px时的水平像素间隔.

    - xxl (number; optional):
        页面宽度大于等于1600px时的水平像素间隔.

- justify (a value equal to: 'start', 'end', 'center', 'space-around', 'space-between'; default 'start'):
    水平排列方式，可选项有`'start'`、`'end'`、`'center'`、`'space-around'`、`'space-between'`
    默认值：`'start'`.

- wrap (boolean; default True):
    是否允许自动换行  默认值：`True`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdRow'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, align=Component.UNDEFINED, gutter=Component.UNDEFINED, justify=Component.UNDEFINED, wrap=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'align', 'gutter', 'justify', 'wrap', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'align', 'gutter', 'justify', 'wrap', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdRow, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdEmpty(Component):
    """An AntdEmpty component.
空状态组件AntdEmpty

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）
    默认值：`'zh-cn'`.

- description (a list of or a singular dash component, string or number | boolean; optional):
    描述信息内容.

- image (string | a value equal to: 'default', 'simple'; default 'default'):
    状态图片地址，也可以使用内置图片，可选项有`'default'`、`'simple'`  默认值：`'default'`.

- imageStyle (dict; optional):
    状态图片css样式.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = ['description']
    _base_nodes = ['description', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdEmpty'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, locale=Component.UNDEFINED, description=Component.UNDEFINED, image=Component.UNDEFINED, imageStyle=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'locale', 'description', 'image', 'imageStyle', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'locale', 'description', 'image', 'imageStyle', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdEmpty, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdImageGroup(Component):
    """An AntdImageGroup component.
图片组合组件AntdImageGroup

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，定义组内需要嵌套的`AntdImage`组件.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- locale (a value equal to: 'zh-cn', 'en-us', 'de-de'; default 'zh-cn'):
    组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）
    默认值：`'zh-cn'`.

- items (list of strings; optional):
    控制图片组合内部实际展示的图片资源地址数组，顺序依次展示.

- fallback (string; optional):
    图片加载失败占位图资源地址.

- preview (dict; default True):
    配置图片预览相关功能，传入`False`时会禁用预览功能  默认值：`True`.

    `preview` is a boolean | dict with keys:

    - src (string; optional):
        自定义预览图链接地址.

    - movable (boolean; optional):
        预览模式下是否可移动图片.

    - mask (a list of or a singular dash component, string or number; optional):
        组件型，用于自定义缩略图遮罩元素.

    - maskClassName (string; optional):
        缩略图遮罩元素css类名.

    - rootClassName (string; optional):
        缩略图根节点css类名.

    - scaleStep (number; optional):
        `1+scaleStep`值为每一步缩放的倍数  默认值：`0.5`.

    - minScale (number; optional):
        最小缩放倍数  默认值：`1`.

    - maxScale (number; optional):
        最大缩放倍数  默认值：`50`.

- visible (boolean; optional):
    监听或设置当前图片组是否处于全屏预览状态.

- current (number; optional):
    监听或控制当前图片预览对应切换到的图片下标.

- disableCurrent (boolean; default True):
    是否关闭基于`current`的当前图片下标受控功能  默认值：`True`.

- toolbarExtra (a list of or a singular dash component, string or number; optional):
    针对预览模式下的工具栏，末尾扩充自定义工具图标元素.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = ['preview.mask', 'toolbarExtra']
    _base_nodes = ['toolbarExtra', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdImageGroup'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, locale=Component.UNDEFINED, items=Component.UNDEFINED, fallback=Component.UNDEFINED, preview=Component.UNDEFINED, visible=Component.UNDEFINED, current=Component.UNDEFINED, disableCurrent=Component.UNDEFINED, toolbarExtra=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'locale', 'items', 'fallback', 'preview', 'visible', 'current', 'disableCurrent', 'toolbarExtra', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'locale', 'items', 'fallback', 'preview', 'visible', 'current', 'disableCurrent', 'toolbarExtra', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdImageGroup, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdCard(Component):
    """An AntdCard component.


Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- actions (a list of or a singular dash component, string or number; optional):
    组件型，底部操作区元素.

- title (a list of or a singular dash component, string or number; optional):
    组件型，标题内容.

- extraLink (dict; optional):
    配置卡片右上角额外链接相关参数.

    `extraLink` is a dict with keys:

    - content (string; optional):
        链接文字内容.

    - href (string; optional):
        链接地址.

    - target (string; optional):
        链接跳转行为.

    - className (string; optional):
        链接css类名.

    - style (dict; optional):
        链接css样式.

- extra (a list of or a singular dash component, string or number; optional):
    组件型，卡片右上角额外元素，优先级高于`extraLink`.

- coverImg (dict; optional):
    配置封面图片相关参数.

    `coverImg` is a dict with keys:

    - src (string; optional):
        图片资源地址.

    - alt (string; optional):
        图片alt信息.

    - className (string; optional):
        图片css类名.

    - style (dict; optional):
        图片css样式.

- bodyStyle (dict; optional):
    内容区css样式.

- headStyle (dict; optional):
    标题css样式.

- bordered (boolean; default True):
    是否渲染边框  默认值：`True`.

- hoverable (boolean; default False):
    是否在鼠标悬停时显示特殊样式  默认值：`False`.

- size (a value equal to: 'default', 'small'; default 'default'):
    卡片尺寸规格，可选项有`'default'`、`'small'`  默认值：`'default'`.

- nClicks (number; default 0):
    监听当前卡片累计点击次数  默认值：`0`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = ['actions', 'title', 'extra']
    _base_nodes = ['actions', 'title', 'extra', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCard'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, actions=Component.UNDEFINED, title=Component.UNDEFINED, extraLink=Component.UNDEFINED, extra=Component.UNDEFINED, coverImg=Component.UNDEFINED, bodyStyle=Component.UNDEFINED, headStyle=Component.UNDEFINED, bordered=Component.UNDEFINED, hoverable=Component.UNDEFINED, size=Component.UNDEFINED, nClicks=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'actions', 'title', 'extraLink', 'extra', 'coverImg', 'bodyStyle', 'headStyle', 'bordered', 'hoverable', 'size', 'nClicks', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'actions', 'title', 'extraLink', 'extra', 'coverImg', 'bodyStyle', 'headStyle', 'bordered', 'hoverable', 'size', 'nClicks', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCard, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdCol(Component):
    """An AntdCol component.
列组件AntdCol

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- span (number; optional):
    列所占宽度份数.

- offset (number; default 0):
    列左侧间隔宽度份数  默认值：`0`.

- order (number; default 0):
    列顺序  默认值：`0`.

- pull (number; default 0):
    列向左移动宽度份数  默认值：`0`.

- push (number; default 0):
    列向右移动宽度份数  默认值：`0`.

- flex (string | number; optional):
    同css中的flex.

- xs (dict; optional):
    配置列在页面宽度小于567px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `xs` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- sm (dict; optional):
    配置列在页面宽度大于等于567px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `sm` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- md (dict; optional):
    配置列在页面宽度大于等于768px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `md` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- lg (dict; optional):
    配置列在页面宽度大于等于992px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `lg` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- xl (dict; optional):
    配置列在页面宽度大于等于1200px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `xl` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- xxl (dict; optional):
    配置列在页面宽度大于等于1600px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `xxl` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCol'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, span=Component.UNDEFINED, offset=Component.UNDEFINED, order=Component.UNDEFINED, pull=Component.UNDEFINED, push=Component.UNDEFINED, flex=Component.UNDEFINED, xs=Component.UNDEFINED, sm=Component.UNDEFINED, md=Component.UNDEFINED, lg=Component.UNDEFINED, xl=Component.UNDEFINED, xxl=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'span', 'offset', 'order', 'pull', 'push', 'flex', 'xs', 'sm', 'md', 'lg', 'xl', 'xxl', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'span', 'offset', 'order', 'pull', 'push', 'flex', 'xs', 'sm', 'md', 'lg', 'xl', 'xxl', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCol, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class AntdAccordion(Component):
    """An AntdAccordion component.
手风琴组件AntdAccordion

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- style (dict; optional):
    当前组件css样式.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- items (list of dicts; optional):
    定义手风琴子项.

    `items` is a list of dicts with keys:

    - children (a list of or a singular dash component, string or number; optional):
        当前子项内部元素.

    - className (string | dict; optional):
        当前子项css类名，支持[动态css](/advanced-classname).

    - style (dict; optional):
        当前子项css样式.

    - key (string | number; required):
        必填，当前子项唯一key值.

    - collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
        当前子项折叠触发方式，可选项有`'header'`、`'disabled'`、`'icon'`.

    - title (a list of or a singular dash component, string or number; optional):
        当前子项标题元素.

    - extra (a list of or a singular dash component, string or number; optional):
        当前子项右上角额外元素.

    - showArrow (boolean; optional):
        是否展示当前手风琴项的箭头图标  默认值：`True`.

    - forceRender (boolean; optional):
        是否强制渲染内部元素  默认值：`False`.

- accordion (boolean; default True):
    是否开启手风琴模式  默认值：`True`.

- activeKey (string | list of strings | number | list of numbers; optional):
    监听或设置当前处于展开状态的手风琴项key值.

- defaultActiveKey (string | list of strings | number | list of numbers; optional):
    设置初始化处于展开状态的手风琴项key值.

- bordered (boolean; default True):
    是否渲染边框  默认值：`True`.

- collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
    设置所有子项折叠触发方式，可选项有`'header'`、`'disabled'`、`'icon'`.

- expandIconPosition (a value equal to: 'left', 'right'; default 'left'):
    设置折叠图标位置，可选项有`'left'`、`'right'`.

- ghost (boolean; default False):
    是否开启透明无边框模式  默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配.

- loading_state (dict; optional)

    `loading_state` is a dict with keys:

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

    - component_name (string; optional):
        Holds the name of the component that is loading."""
    _children_props = ['items[].children', 'items[].title', 'items[].extra']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAccordion'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, key=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, items=Component.UNDEFINED, accordion=Component.UNDEFINED, activeKey=Component.UNDEFINED, defaultActiveKey=Component.UNDEFINED, bordered=Component.UNDEFINED, collapsible=Component.UNDEFINED, expandIconPosition=Component.UNDEFINED, ghost=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'key', 'style', 'className', 'items', 'accordion', 'activeKey', 'defaultActiveKey', 'bordered', 'collapsible', 'expandIconPosition', 'ghost', 'data-*', 'aria-*', 'loading_state']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'items', 'accordion', 'activeKey', 'defaultActiveKey', 'bordered', 'collapsible', 'expandIconPosition', 'ghost', 'data-*', 'aria-*', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAccordion, self).__init__(**args)
